package com.jiuqi.sql;

import java.util.ArrayList;
import java.util.List;

/* loaded from: com_jiuqi_sql.jar:com/jiuqi/sql/SQLPretreatment.class */
public class SQLPretreatment {
    private String originSQL;
    private String sql;
    private static final char[] BLANK_SET = {' ', '\t', '\r', '\n'};
    private boolean toUpperCase = false;
    private boolean ignoreComment = false;
    private List params = new ArrayList();

    public SQLPretreatment(String sql) {
        this.originSQL = sql;
    }

    public void execute() throws DBException {
        reset();
        StringBuffer sqlBuffer = new StringBuffer();
        build(sqlBuffer);
        this.sql = sqlBuffer.toString().trim();
    }

    public String getSQL() {
        return this.sql;
    }

    public String[] getParamNames() {
        return (String[]) this.params.toArray(new String[0]);
    }

    public void setToUpperCase(boolean toUpperCase) {
        this.toUpperCase = toUpperCase;
    }

    public boolean getToUpperCase() {
        return this.toUpperCase;
    }

    public void setIgnoreComment(boolean ignoreComment) {
        this.ignoreComment = ignoreComment;
    }

    public boolean getIgnoreComment() {
        return this.ignoreComment;
    }

    private void reset() {
        this.sql = null;
        this.params.clear();
    }

    private char convertChar(char ch) {
        return this.toUpperCase ? Character.toUpperCase(ch) : ch;
    }

    private void build(StringBuffer buffer) throws DBException {
        CharReader reader = new CharReader(this, null);
        while (!reader.isEnd()) {
            char ch = reader.read();
            switch (ch) {
                case 0:
                case ';':
                    return;
                case '\'':
                    buffer.append(ch);
                    if (!readToStringEnd(reader, buffer)) {
                        throw new DBException("SQL语法错误：含有未结束的字符串！");
                    }
                    break;
                case '-':
                    if (reader.peek() == '-') {
                        reader.read();
                        if (!this.ignoreComment) {
                            buffer.append("--");
                        }
                        gotoNextLine(reader, buffer);
                        break;
                    } else {
                        buffer.append(ch);
                        break;
                    }
                case '/':
                    if (reader.peek() == '*') {
                        reader.read();
                        if (!this.ignoreComment) {
                            buffer.append("/*");
                        }
                        gotoCommentEnd(reader, buffer);
                        break;
                    } else {
                        buffer.append(ch);
                        break;
                    }
                case '?':
                    buffer.append(ch);
                    String paramName = readParamName(reader);
                    this.params.add(paramName);
                    break;
                case 'G':
                case 'g':
                    if (reader.check(-1, BLANK_SET) && reader.check(0, new char[]{'o', 'O'}) && reader.check(1, BLANK_SET)) {
                        return;
                    }
                    buffer.append(convertChar(ch));
                    break;
                default:
                    buffer.append(convertChar(ch));
                    break;
            }
        }
    }

    private void gotoNextLine(CharReader reader, StringBuffer buffer) {
        while (!reader.isEnd()) {
            char ch = reader.read();
            if (ch == '\r' || ch == '\n') {
                buffer.append(ch);
                return;
            } else if (!this.ignoreComment) {
                buffer.append(ch);
            }
        }
    }

    private void gotoCommentEnd(CharReader reader, StringBuffer buffer) {
        while (!reader.isEnd()) {
            char ch = reader.read();
            if (ch == '*' && reader.peek() == '/') {
                reader.read();
                buffer.append(this.ignoreComment ? " " : "*/");
                return;
            } else if (!this.ignoreComment) {
                buffer.append(ch);
            }
        }
    }

    private boolean readToStringEnd(CharReader reader, StringBuffer buffer) {
        while (!reader.isEnd()) {
            char ch = reader.read();
            buffer.append(ch);
            if (ch == '\'') {
                return true;
            }
        }
        return false;
    }

    private String readParamName(CharReader reader) {
        char ch;
        StringBuffer paramName = new StringBuffer();
        while (!reader.isEnd() && (((ch = reader.peek()) >= 'a' && ch <= 'z') || ((ch >= 'A' && ch <= 'Z') || ((ch >= '0' && ch <= '9') || ch == '_' || ch == '@')))) {
            paramName.append(ch);
            reader.read();
        }
        return paramName.toString();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_jiuqi_sql.jar:com/jiuqi/sql/SQLPretreatment$CharReader.class */
    public class CharReader {
        private int curPos;
        public static final char EOF = 0;

        private CharReader() {
            this.curPos = 0;
        }

        /* synthetic */ CharReader(SQLPretreatment sQLPretreatment, CharReader charReader) {
            this();
        }

        public boolean isEnd() {
            return SQLPretreatment.this.originSQL == null || this.curPos >= SQLPretreatment.this.originSQL.length();
        }

        public char read() {
            if (!isEnd()) {
                String str = SQLPretreatment.this.originSQL;
                int i = this.curPos;
                this.curPos = i + 1;
                return str.charAt(i);
            }
            return (char) 0;
        }

        public char peek() {
            if (!isEnd()) {
                return SQLPretreatment.this.originSQL.charAt(this.curPos);
            }
            return (char) 0;
        }

        public char peekNext() {
            if (SQLPretreatment.this.originSQL != null && this.curPos + 1 < SQLPretreatment.this.originSQL.length()) {
                return SQLPretreatment.this.originSQL.charAt(this.curPos + 1);
            }
            return (char) 0;
        }

        public char peek(int offset) {
            int newPos;
            if (SQLPretreatment.this.originSQL != null && (newPos = this.curPos + offset) >= 0 && newPos < SQLPretreatment.this.originSQL.length()) {
                return SQLPretreatment.this.originSQL.charAt(newPos);
            }
            return (char) 0;
        }

        public boolean check(int offset, char[] charSet) {
            if (charSet == null) {
                return false;
            }
            char ch = peek(offset);
            for (char c : charSet) {
                if (c == ch) {
                    return true;
                }
            }
            return false;
        }
    }
}
